@@ -22,13 +22,13 @@ class Algorithm(Serializable, ABC):
     Algorithms must implement two methods:
     :func:`match`, which returns whether the algorithm should be run given
     the current event and state, and :func:`apply`, which makes an in-place
-    change to the State.
+    change to the :class:`State`.
     """
 
     @property
     def find_unused_parameters(self) -> bool:
         """Indicates that the effect of this algorithm may cause some model
-        parameters to be unused.
+        parameters to be unused. Defaults to False.
 
         Used to tell DDP that some parameters will be frozen during
         training and hence it should not expect gradients from them.
@@ -37,6 +37,16 @@ class Algorithm(Serializable, ABC):
         """
         return False
 
+    @property
+    def backwards_create_graph(self) -> bool:
+        """Indicates that this algorithm requires a second derivative
+        to be computed. Defaults to False.
+
+        If True, create_graph=True will be passed to loss.backward()
+        which wil result in the graph of the gradient also being constructed.
+        """
+        return False
+
     @abstractmethod
     def match(self, event: Event, state: State) -> bool:
         """Determines whether this algorithm should run, given the current
@@ -66,7 +76,7 @@ class Algorithm(Serializable, ABC):
     def apply(self, event: Event, state: State, logger: Logger) -> Optional[int]:
         """Applies the algorithm to make an in-place change to the State
 
-        Can optionally return an exit code to be stored in a :class:`Trace`.
+        Can optionally return an exit code to be stored in a :class:`~composer.core.engine.Trace`.
 
         Args:
             event (:class:`Event`): The current event.
@@ -74,8 +84,8 @@ class Algorithm(Serializable, ABC):
             logger (:class:`Logger`): A logger to use for
                 logging algorithm-specific metrics.
         Returns:
-            ``int`` or ``None``: exit code that is stored in :class:`Trace`
-            and made accessible for debugging.
+            int or None: exit code that is stored in :class:`~composer.core.engine.Trace`
+                and made accessible for debugging.
         """
         raise NotImplementedError(f'implement apply() required for {self.__class__.__name__}')
 
