@@ -4,19 +4,20 @@ from __future__ import annotations
 
 import warnings
 from abc import ABC
-from typing import TYPE_CHECKING, List, Optional, Tuple, final
+from typing import TYPE_CHECKING, List, Optional, Tuple
 
 from composer.core.callback import Callback, RankZeroCallback
 from composer.core.logging.logger import Logger
-from composer.utils.ddp import is_rank_set, is_rank_zero
+from composer.utils.ddp import is_rank_zero
 
 if TYPE_CHECKING:
     from composer.core.logging.logger import LogLevel, TLogData
     from composer.core.state import State
 
-
-class DeferredLogMetricWarning(UserWarning):
-    pass
+try:
+    from typing import final
+except ImportError:
+    final = lambda x: x  # final is not available in python 3.7
 
 
 class BaseLoggerBackend(Callback, ABC):
@@ -115,7 +116,7 @@ class RankZeroLoggerBackend(BaseLoggerBackend, RankZeroCallback, ABC):
 
     @final
     def will_log(self, state: State, log_level: LogLevel) -> bool:
-        if state.is_rank_set and not state.is_rank_zero:
+        if not state.is_rank_zero:
             return False
         return self._will_log(state, log_level)
 
@@ -137,15 +138,14 @@ class RankZeroLoggerBackend(BaseLoggerBackend, RankZeroCallback, ABC):
 
     @final
     def log_metric(self, epoch: int, step: int, log_level: LogLevel, data: TLogData) -> None:
-        if is_rank_set() and not is_rank_zero():
+        if not is_rank_zero():
             # no log if not on rank zero, clear deferred calls to free memory
             self._deferred_log_metric_calls = None
             return
         if self._deferred_log_metric_calls is not None:
-            warnings.warn(
-                f"{self.__class__.__name__}.log_metric() was invoked before training_start()."
-                "This log call will be queued and processed after training_start().",
-                category=DeferredLogMetricWarning)
+            warnings.warn(f"DeferredLogMetricWarning: {self.__class__.__name__}.log_metric()"
+                          "was invoked before training_start()."
+                          "This log call will be queued and processed after training_start().")
             self._deferred_log_metric_calls.append((epoch, step, log_level, data))
             return
         return self._log_metric(epoch, step, log_level, data)
