@@ -6,6 +6,13 @@ from composer.models.efficientnets import EfficientNet
 
 
 class EfficientNetB0(MosaicClassifier):
+    """An EfficientNet-b0 model extending :class:`MosaicClassifier`.
+
+    Based off of this `paper <https://arxiv.org/abs/1905.11946>`_.
+
+    Args:
+        hparams (EfficientNetB0Hparams): The hyperparameters for the model.
+    """
 
     def __init__(self, hparams: EfficientNetB0Hparams) -> None:
         model = EfficientNet.get_model_from_name(
