@@ -6,7 +6,7 @@ from composer.models.resnet101.resnet101_hparams import ResNet101Hparams as ResN
 _task = 'Image Classification'
 _dataset = 'ImageNet'
 _name = 'ResNet101'
-_quality = ''
+_quality = '78.10'
 _metric = 'Top-1 Accuracy'
-_ttt = '?'
-_hparams = 'hparams.yaml'
+_ttt = '8h 15m'
+_hparams = 'resnet101.yaml'
