@@ -6,7 +6,7 @@ from composer.models.resnet56_cifar10.resnet56_cifar10_hparams import CIFARResNe
 _task = 'Image Classification'
 _dataset = 'CIFAR10'
 _name = 'ResNet56'
-_quality = ''
+_quality = '93.1'
 _metric = 'Top-1 Accuracy'
-_ttt = '?'
-_hparams = 'hparams.yaml'
+_ttt = '15m'
+_hparams = 'resnet56_cifar10.yaml'
