@@ -15,7 +15,7 @@ import composer
 import composer.datasets as datasets
 from composer.algorithms import AlgorithmHparams, get_algorithm_registry
 from composer.callbacks import (BenchmarkerHparams, CallbackHparams, GradMonitorHparams, LRMonitorHparams,
-                                SpeedMonitorHparams, TorchProfilerHparams)
+                                MemoryMonitorHparams, SpeedMonitorHparams, TorchProfilerHparams)
 from composer.core.types import Precision
 from composer.datasets import DataloaderHparams
 from composer.loggers import (BaseLoggerBackendHparams, FileLoggerBackendHparams, TQDMLoggerBackendHparams,
@@ -26,6 +26,7 @@ from composer.optim import (AdamHparams, AdamWHparams, DecoupledAdamWHparams, De
                             RAdamHparams, RMSPropHparams, SchedulerHparams, SGDHparams, scheduler)
 from composer.trainer.ddp import DDPHparams
 from composer.trainer.devices import CPUDeviceHparams, DeviceHparams, GPUDeviceHparams
+from composer.utils.ddp import get_world_size
 
 if TYPE_CHECKING:
     from composer.trainer.trainer import Trainer
@@ -73,11 +74,12 @@ dataset_registry = {
 algorithms_registry = get_algorithm_registry()
 
 callback_registry = {
-    "pytorch_profiler": TorchProfilerHparams,
+    "torch_profiler": TorchProfilerHparams,
     "speed_monitor": SpeedMonitorHparams,
     "benchmarker": BenchmarkerHparams,
     "lr_monitor": LRMonitorHparams,
     "grad_monitor": GradMonitorHparams,
+    "memory_monitor": MemoryMonitorHparams,
 }
 
 logger_registry = {
@@ -164,7 +166,10 @@ class TrainerHparams(hp.Hparams):
         "Unit for the checkpoint save interval -- should be 'ep' for epochs; 'ba' for batches, or None to disable checkpointing",
         default=None)
     checkpoint_interval: int = hp.optional(doc="Interval for checkpointing.", default=1)
-    checkpoint_folder: str = hp.optional(doc="Folder in which to save checkpoint files", default="checkpoints")
+    checkpoint_folder: str = hp.optional(
+        doc="Folder in which to save checkpoint files. Relative to the run directory, if set."
+        "Defaults to `checkpoints`.",
+        default="checkpoints")
     deterministic_mode: bool = hp.optional(doc="Run the model deterministically. Experimental. Performance"
                                            "degradations expected. Certain Torch modules may not have"
                                            "deterministic implementations, which will result in a crash.",
@@ -173,24 +178,21 @@ class TrainerHparams(hp.Hparams):
     compute_training_metrics: bool = hp.optional(doc="Log validation metrics on training data", default=False)
     log_level: str = hp.optional(doc="Python loglevel to use composer", default="INFO")
 
+    ddp_sync_strategy: Optional[str] = hp.optional(doc="Strategy for DDP syncing", default=None)
+
     def validate(self):
         super().validate()
 
-        num_procs = 1
-        if isinstance(self.device, GPUDeviceHparams) and self.device.n_gpus > 0:
-            num_procs = self.device.n_gpus
-        if isinstance(self.device, CPUDeviceHparams) and self.device.n_cpus > 0:
-            num_procs = self.device.n_cpus
+        world_size = get_world_size()
 
-        if self.total_batch_size % (num_procs * self.ddp.num_nodes) != 0:
+        if self.total_batch_size % world_size != 0:
             raise ValueError(
-                f"batch size ({self.total_batch_size}) not divisible by the number of proccesses per node ({num_procs}) "
-                f"times the number of nodes ({self.ddp.num_nodes} ")
+                f"batch size ({self.total_batch_size}) not divisible by the total number of processes ({world_size})")
 
-        if self.eval_batch_size % (num_procs * self.ddp.num_nodes) != 0:
+        if self.eval_batch_size % world_size != 0:
             raise ValueError(
-                f"eval batch size ({self.eval_batch_size}) not divisible by the number of proccesses per node ({num_procs}) "
-                f"times the number of nodes ({self.ddp.num_nodes}")
+                f"eval batch size ({self.eval_batch_size}) not divisible by the total number of processes ({world_size}) "
+            )
 
     def initialize_object(self) -> Trainer:
         from composer.trainer.trainer import Trainer
@@ -219,6 +221,6 @@ class TrainerHparams(hp.Hparams):
             "models",
             f"{model}.yaml",
         )
-        trainer_hparams = TrainerHparams.create(model_hparams_file)
+        trainer_hparams = TrainerHparams.create(model_hparams_file, cli_args=False)
         assert isinstance(trainer_hparams, TrainerHparams), "trainer hparams should return an instance of self"
         return trainer_hparams
