@@ -2,7 +2,9 @@
 
 from composer.utils import augmentation_primitives as augmentation_primitives
 from composer.utils.ddp import get_global_rank as get_global_rank
-from composer.utils.ddp import is_rank_set as is_rank_set
+from composer.utils.ddp import get_local_rank as get_local_rank
+from composer.utils.ddp import get_local_world_size as get_local_world_size
+from composer.utils.ddp import get_world_size as get_world_size
 from composer.utils.ddp import is_rank_zero as is_rank_zero
 from composer.utils.determinism import get_random_seed as get_random_seed
 from composer.utils.determinism import seed_all as seed_all
@@ -15,4 +17,3 @@ from composer.utils.tables import build_markdown_table as build_markdown_table
 from composer.utils.tables import get_metadata as get_metadata
 from composer.utils.tables import list_dirs as list_dirs
 from composer.utils.tables import update_table_in_file as update_table_in_file
-from composer.utils.tensor import make_empty_tensor as make_empty_tensor
